@@ -19,8 +19,8 @@ macro_rules! buf {
         $crate::helper::Buffer::new()
     }};
 
-    ($s:expr) => {{
-        $crate::helper::Buffer::from($s)
+    ($($s:expr),+) => {{
+        $crate::helper::Buffer::from([$(&$s[..]),+].concat())
     }};
 }
 
@@ -62,7 +62,7 @@ impl Buffer {
 impl Debug for Buffer {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         let mut buf: Vec<u8> = Vec::with_capacity(self.inner.len());
-        &self.inner.iter().for_each(|v| {
+        let _ = &self.inner.iter().for_each(|v| {
             for e in escape_default(*v) {
                 buf.push(e);
             }
@@ -104,6 +104,14 @@ impl From<String> for Buffer {
     }
 }
 
+impl From<Vec<u8>> for Buffer {
+    fn from(b: Vec<u8>) -> Self {
+        Self {
+            inner: Vec::from(b),
+        }
+    }
+}
+
 impl<const N: usize> From<&[u8; N]> for Buffer {
     fn from(b: &[u8; N]) -> Self {
         Self {
